@@ -15,7 +15,7 @@ class Format:
         """
         raise NotImplementedError()
 
-    def export_data(self, dataset, escape_output=False, **kwargs):
+    def export_data(self, dataset, **kwargs):
         """
         Returns format representation for given dataset.
         """
@@ -31,7 +31,7 @@ class Format:
         """
         Returns mode for opening files.
         """
-        return 'rb'
+        return "rb"
 
     def get_extension(self):
         """
@@ -42,7 +42,7 @@ class Format:
     def get_content_type(self):
         # For content types see
         # https://www.iana.org/assignments/media-types/media-types.xhtml
-        return 'application/octet-stream'
+        return "application/octet-stream"
 
     @classmethod
     def is_available(cls):
@@ -57,7 +57,7 @@ class Format:
 
 class TablibFormat(Format):
     TABLIB_MODULE = None
-    CONTENT_TYPE = 'application/octet-stream'
+    CONTENT_TYPE = "application/octet-stream"
 
     def __init__(self, encoding=None):
         self.encoding = encoding
@@ -68,7 +68,7 @@ class TablibFormat(Format):
         """
         if not self.TABLIB_MODULE:
             raise AttributeError("TABLIB_MODULE must be defined")
-        key = self.TABLIB_MODULE.split('.')[-1].replace('_', '')
+        key = self.TABLIB_MODULE.split(".")[-1].replace("_", "")
         return registry.get_format(key)
 
     @classmethod
@@ -86,8 +86,6 @@ class TablibFormat(Format):
         return tablib.import_set(in_stream, format=self.get_title(), **kwargs)
 
     def export_data(self, dataset, **kwargs):
-        # remove the deprecated `escape_output` param if present
-        kwargs.pop("escape_output", None)
         if kwargs.pop("escape_html", None):
             self._escape_html(dataset)
         if kwargs.pop("escape_formulae", None):
@@ -101,10 +99,10 @@ class TablibFormat(Format):
         return self.CONTENT_TYPE
 
     def can_import(self):
-        return hasattr(self.get_format(), 'import_set')
+        return hasattr(self.get_format(), "import_set")
 
     def can_export(self):
-        return hasattr(self.get_format(), 'export_set')
+        return hasattr(self.get_format(), "export_set")
 
     def _escape_html(self, dataset):
         for _ in dataset:
@@ -123,72 +121,65 @@ class TablibFormat(Format):
 
 
 class TextFormat(TablibFormat):
-
     def create_dataset(self, in_stream, **kwargs):
         if isinstance(in_stream, bytes) and self.encoding:
             in_stream = in_stream.decode(self.encoding)
         return super().create_dataset(in_stream, **kwargs)
 
     def get_read_mode(self):
-        return 'r'
+        return "r"
 
     def is_binary(self):
         return False
 
 
 class CSV(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._csv'
-    CONTENT_TYPE = 'text/csv'
+    TABLIB_MODULE = "tablib.formats._csv"
+    CONTENT_TYPE = "text/csv"
 
 
 class JSON(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._json'
-    CONTENT_TYPE = 'application/json'
+    TABLIB_MODULE = "tablib.formats._json"
+    CONTENT_TYPE = "application/json"
 
 
 class YAML(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._yaml'
+    TABLIB_MODULE = "tablib.formats._yaml"
     # See https://stackoverflow.com/questions/332129/yaml-mime-type
-    CONTENT_TYPE = 'text/yaml'
+    CONTENT_TYPE = "text/yaml"
 
 
 class TSV(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._tsv'
-    CONTENT_TYPE = 'text/tab-separated-values'
+    TABLIB_MODULE = "tablib.formats._tsv"
+    CONTENT_TYPE = "text/tab-separated-values"
 
     def create_dataset(self, in_stream, **kwargs):
         return super().create_dataset(in_stream, **kwargs)
 
 
 class ODS(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._ods'
-    CONTENT_TYPE = 'application/vnd.oasis.opendocument.spreadsheet'
+    TABLIB_MODULE = "tablib.formats._ods"
+    CONTENT_TYPE = "application/vnd.oasis.opendocument.spreadsheet"
 
 
 class HTML(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._html'
-    CONTENT_TYPE = 'text/html'
+    TABLIB_MODULE = "tablib.formats._html"
+    CONTENT_TYPE = "text/html"
 
-    def export_data(self, dataset, escape_output=False, **kwargs):
-        if escape_output:
-            warnings.warn(
-                "escape_output flag now deprecated - "
-                "this will be removed in a future release",
-                DeprecationWarning,
-            )
-            super()._escape_html(dataset)
+    def export_data(self, dataset, **kwargs):
         return super().export_data(dataset, **kwargs)
 
 
 class XLS(TablibFormat):
-    TABLIB_MODULE = 'tablib.formats._xls'
-    CONTENT_TYPE = 'application/vnd.ms-excel'
+    TABLIB_MODULE = "tablib.formats._xls"
+    CONTENT_TYPE = "application/vnd.ms-excel"
 
     def create_dataset(self, in_stream):
         """
         Create dataset from first sheet.
         """
         import xlrd
+
         xls_book = xlrd.open_workbook(file_contents=in_stream)
         dataset = tablib.Dataset()
         sheet = xls_book.sheets()[0]
@@ -200,8 +191,8 @@ class XLS(TablibFormat):
 
 
 class XLSX(TablibFormat):
-    TABLIB_MODULE = 'tablib.formats._xlsx'
-    CONTENT_TYPE = 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
+    TABLIB_MODULE = "tablib.formats._xlsx"
+    CONTENT_TYPE = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
 
     def create_dataset(self, in_stream):
         """
@@ -212,7 +203,9 @@ class XLSX(TablibFormat):
         import openpyxl
 
         # 'data_only' means values are read from formula cells, not the formula itself
-        xlsx_book = openpyxl.load_workbook(BytesIO(in_stream), read_only=True, data_only=True)
+        xlsx_book = openpyxl.load_workbook(
+            BytesIO(in_stream), read_only=True, data_only=True
+        )
 
         dataset = tablib.Dataset()
         sheet = xlsx_book.active
@@ -226,15 +219,27 @@ class XLSX(TablibFormat):
             dataset.append(row_values)
         return dataset
 
+    def export_data(self, dataset, **kwargs):
+        # #1698 temporary catch for deprecation warning in openpyxl
+        # this catch block must be removed when openpyxl updated
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", category=DeprecationWarning)
+            return super().export_data(dataset, **kwargs)
+
+
 #: These are the default formats for import and export. Whether they can be
 #: used or not is depending on their implementation in the tablib library.
-DEFAULT_FORMATS = [fmt for fmt in (
-    CSV,
-    XLS,
-    XLSX,
-    TSV,
-    ODS,
-    JSON,
-    YAML,
-    HTML,
-) if fmt.is_available()]
+DEFAULT_FORMATS = [
+    fmt
+    for fmt in (
+        CSV,
+        XLS,
+        XLSX,
+        TSV,
+        ODS,
+        JSON,
+        YAML,
+        HTML,
+    )
+    if fmt.is_available()
+]
